@@ -64,6 +64,11 @@ class behat_enrol extends behat_base {
         // Set form fields.
         $this->execute("behat_forms::i_set_the_following_fields_to_these_values", $table);
 
+        // Ensure we get button in focus, before pressing button.
+        if ($this->running_javascript()) {
+            $this->execute("behat_general::i_take_focus_off_field", array(get_string('addinstance', 'enrol'), "button"));
+        }
+
         // Save changes.
         $this->execute("behat_forms::press_button", get_string('addinstance', 'enrol'));
 
