@@ -42,7 +42,7 @@ EDITOR.prototype = {
      * @type M.core.dialogue
      * @protected
      */
-    dialogue : null,
+    dialogue: null,
 
     /**
      * The panel used for all action menu displays.
@@ -51,7 +51,7 @@ EDITOR.prototype = {
      * @type Y.Node
      * @protected
      */
-    panel : null,
+    panel: null,
 
     /**
      * The number of pages in the pdf.
@@ -60,7 +60,7 @@ EDITOR.prototype = {
      * @type Number
      * @protected
      */
-    pagecount : 0,
+    pagecount: 0,
 
     /**
      * The active page in the editor.
@@ -69,7 +69,7 @@ EDITOR.prototype = {
      * @type Number
      * @protected
      */
-    currentpage : 0,
+    currentpage: 0,
 
     /**
      * A list of page objects. Each page has a list of comments and annotations.
@@ -78,7 +78,7 @@ EDITOR.prototype = {
      * @type array
      * @protected
      */
-    pages : [],
+    pages: [],
 
     /**
      * The yui node for the loading icon.
@@ -87,7 +87,7 @@ EDITOR.prototype = {
      * @type Node
      * @protected
      */
-    loadingicon : null,
+    loadingicon: null,
 
     /**
      * Image object of the current page image.
@@ -96,7 +96,7 @@ EDITOR.prototype = {
      * @type Image
      * @protected
      */
-    pageimage : null,
+    pageimage: null,
 
     /**
      * YUI Graphic class for drawing shapes.
@@ -105,7 +105,7 @@ EDITOR.prototype = {
      * @type Graphic
      * @protected
      */
-    graphic : null,
+    graphic: null,
 
     /**
      * Info about the current edit operation.
@@ -114,7 +114,7 @@ EDITOR.prototype = {
      * @type M.assignfeedback_editpdf.edit
      * @protected
      */
-    currentedit : new M.assignfeedback_editpdf.edit(),
+    currentedit: new M.assignfeedback_editpdf.edit(),
 
     /**
      * Current drawable.
@@ -123,7 +123,7 @@ EDITOR.prototype = {
      * @type M.assignfeedback_editpdf.drawable|false
      * @protected
      */
-    currentdrawable : false,
+    currentdrawable: false,
 
     /**
      * Current drawables.
@@ -132,7 +132,7 @@ EDITOR.prototype = {
      * @type array(M.assignfeedback_editpdf.drawable)
      * @protected
      */
-    drawables : [],
+    drawables: [],
 
     /**
      * Current comment when the comment menu is open.
@@ -140,7 +140,7 @@ EDITOR.prototype = {
      * @type M.assignfeedback_editpdf.comment
      * @protected
      */
-    currentcomment : null,
+    currentcomment: null,
 
     /**
      * Current annotation when the select tool is used.
@@ -148,7 +148,7 @@ EDITOR.prototype = {
      * @type M.assignfeedback_editpdf.annotation
      * @protected
      */
-    currentannotation : null,
+    currentannotation: null,
 
     /**
      * Last selected annotation tool
@@ -164,7 +164,7 @@ EDITOR.prototype = {
      * @type M.assignfeedback_editpdf.quickcommentlist
      * @protected
      */
-    quicklist : null,
+    quicklist: null,
 
     /**
      * The search comments window.
@@ -172,7 +172,7 @@ EDITOR.prototype = {
      * @type M.core.dialogue
      * @protected
      */
-    searchcommentswindow : null,
+    searchcommentswindow: null,
 
 
     /**
@@ -181,7 +181,7 @@ EDITOR.prototype = {
      * @type String
      * @protected
      */
-    currentstamp : null,
+    currentstamp: null,
 
     /**
      * The stamps.
@@ -189,7 +189,7 @@ EDITOR.prototype = {
      * @type Array
      * @protected
      */
-    stamps : [],
+    stamps: [],
 
     /**
      * Prevent new comments from appearing
@@ -199,13 +199,13 @@ EDITOR.prototype = {
      * @type Boolean
      * @public
      */
-    editingcomment : false,
+    editingcomment: false,
 
     /**
      * Called during the initialisation process of the object.
      * @method initializer
      */
-    initializer : function() {
+    initializer: function() {
         var link;
 
         link = Y.one('#' + this.get('linkid'));
@@ -239,7 +239,7 @@ EDITOR.prototype = {
      * Called to show/hide buttons and set the current colours/stamps.
      * @method refresh_button_state
      */
-    refresh_button_state : function() {
+    refresh_button_state: function() {
         var button, currenttoolnode, imgurl, drawingregion;
 
         // Initalise the colour buttons.
@@ -274,7 +274,7 @@ EDITOR.prototype = {
      * Called to get the bounds of the drawing region.
      * @method get_canvas_bounds
      */
-    get_canvas_bounds : function() {
+    get_canvas_bounds: function() {
         var canvas = this.get_dialogue_element(SELECTOR.DRAWINGCANVAS),
             offsetcanvas = canvas.getXY(),
             offsetleft = offsetcanvas[0],
@@ -290,7 +290,7 @@ EDITOR.prototype = {
      * @method get_canvas_coordinates
      * @param M.assignfeedback_editpdf.point point in window coordinats.
      */
-    get_canvas_coordinates : function(point) {
+    get_canvas_coordinates: function(point) {
         var bounds = this.get_canvas_bounds(),
             newpoint = new M.assignfeedback_editpdf.point(point.x - bounds.x, point.y - bounds.y);
 
@@ -305,7 +305,7 @@ EDITOR.prototype = {
      * @method get_window_coordinates
      * @param M.assignfeedback_editpdf.point point in window coordinats.
      */
-    get_window_coordinates : function(point) {
+    get_window_coordinates: function(point) {
         var bounds = this.get_canvas_bounds(),
             newpoint = new M.assignfeedback_editpdf.point(point.x + bounds.x, point.y + bounds.y);
 
@@ -316,7 +316,7 @@ EDITOR.prototype = {
      * Open the edit-pdf editor in the panel in the page instead of a popup.
      * @method open_in_panel
      */
-    open_in_panel : function(panel) {
+    open_in_panel: function(panel) {
         var drawingcanvas, drawingregion;
 
         this.panel = panel;
@@ -326,7 +326,7 @@ EDITOR.prototype = {
         this.loadingicon = this.get_dialogue_element(SELECTOR.LOADINGICON);
 
         drawingcanvas = this.get_dialogue_element(SELECTOR.DRAWINGCANVAS);
-        this.graphic = new Y.Graphic({render : drawingcanvas});
+        this.graphic = new Y.Graphic({render: drawingcanvas});
 
         drawingregion = this.get_dialogue_element(SELECTOR.DRAWINGREGION);
         drawingregion.on('scroll', this.move_canvas, this);
@@ -346,8 +346,9 @@ EDITOR.prototype = {
      * Called to open the pdf editing dialogue.
      * @method link_handler
      */
-    link_handler : function(e) {
-        var drawingcanvas, drawingregion, resize = true;
+    link_handler: function(e) {
+        var drawingcanvas, drawingregion;
+        var resize = true;
         e.preventDefault();
 
         if (!this.dialogue) {
@@ -367,7 +368,7 @@ EDITOR.prototype = {
             this.loadingicon = this.get_dialogue_element(SELECTOR.LOADINGICON);
 
             drawingcanvas = this.get_dialogue_element(SELECTOR.DRAWINGCANVAS);
-            this.graphic = new Y.Graphic({render : drawingcanvas});
+            this.graphic = new Y.Graphic({render: drawingcanvas});
 
             drawingregion = this.get_dialogue_element(SELECTOR.DRAWINGREGION);
             drawingregion.on('scroll', this.move_canvas, this);
@@ -399,7 +400,7 @@ EDITOR.prototype = {
      * Called to load the information and annotations for all pages.
      * @method load_all_pages
      */
-    load_all_pages : function() {
+    load_all_pages: function() {
         var ajaxurl = AJAXBASE,
             config,
             checkconversionstatus,
@@ -409,13 +410,13 @@ EDITOR.prototype = {
             method: 'get',
             context: this,
             sync: false,
-            data : {
-                sesskey : M.cfg.sesskey,
-                action : 'loadallpages',
-                userid : this.get('userid'),
-                attemptnumber : this.get('attemptnumber'),
-                assignmentid : this.get('assignmentid'),
-                readonly : this.get('readonly') ? 1 : 0
+            data: {
+                sesskey: M.cfg.sesskey,
+                action: 'loadallpages',
+                userid: this.get('userid'),
+                attemptnumber: this.get('attemptnumber'),
+                assignmentid: this.get('assignmentid'),
+                readonly: this.get('readonly') ? 1 : 0
             },
             on: {
                 success: function(tid, response) {
@@ -435,12 +436,12 @@ EDITOR.prototype = {
                 method: 'get',
                 context: this,
                 sync: false,
-                data : {
-                    sesskey : M.cfg.sesskey,
-                    action : 'conversionstatus',
-                    userid : this.get('userid'),
-                    attemptnumber : this.get('attemptnumber'),
-                    assignmentid : this.get('assignmentid')
+                data: {
+                    sesskey: M.cfg.sesskey,
+                    action: 'conversionstatus',
+                    userid: this.get('userid'),
+                    attemptnumber: this.get('attemptnumber'),
+                    assignmentid: this.get('assignmentid')
                 },
                 on: {
                     success: function(tid, response) {
@@ -460,7 +461,7 @@ EDITOR.prototype = {
 
                             // New ajax request delayed of a second.
                             M.util.js_pending('checkconversionstatus');
-                            Y.later(1000, this, function () {
+                            Y.later(1000, this, function() {
                                 M.util.js_complete('checkconversionstatus');
                                 Y.io(AJAXBASEPROGRESS, checkconversionstatus);
                             });
@@ -472,7 +473,7 @@ EDITOR.prototype = {
                         // and if the ajax call did not produce 5 errors in the row.
                         if (this.pagecount === 0 && ajax_error_total < 5) {
                             M.util.js_pending('checkconversionstatus');
-                            Y.later(1000, this, function () {
+                            Y.later(1000, this, function() {
                                 M.util.js_complete('checkconversionstatus');
                                 Y.io(AJAXBASEPROGRESS, checkconversionstatus);
                             });
@@ -484,7 +485,7 @@ EDITOR.prototype = {
             // We start the AJAX "generated page total number" call a second later to give a chance to
             // the AJAX "combined pdf generation" call to clean the previous submission images.
             M.util.js_pending('checkconversionstatus');
-            Y.later(1000, this, function () {
+            Y.later(1000, this, function() {
                 ajax_error_total = 0;
                 M.util.js_complete('checkconversionstatus');
                 Y.io(AJAXBASEPROGRESS, checkconversionstatus);
@@ -498,7 +499,7 @@ EDITOR.prototype = {
      * @protected
      * @method all_pages_loaded
      */
-    all_pages_loaded : function(responsetext) {
+    all_pages_loaded: function(responsetext) {
         var data, i, j, comment, error;
         try {
             data = Y.JSON.parse(responsetext);
@@ -507,7 +508,7 @@ EDITOR.prototype = {
                     this.dialogue.hide();
                 }
                 // Display alert dialogue.
-                error = new M.core.alert({ message: M.util.get_string('cannotopenpdf', 'assignfeedback_editpdf') });
+                error = new M.core.alert({message: M.util.get_string('cannotopenpdf', 'assignfeedback_editpdf')});
                 error.show();
                 return;
             }
@@ -516,7 +517,7 @@ EDITOR.prototype = {
                 this.dialogue.hide();
             }
             // Display alert dialogue.
-            error = new M.core.alert({ title: M.util.get_string('cannotopenpdf', 'assignfeedback_editpdf')});
+            error = new M.core.alert({title: M.util.get_string('cannotopenpdf', 'assignfeedback_editpdf')});
             error.show();
             return;
         }
@@ -558,7 +559,7 @@ EDITOR.prototype = {
      * @method get_stamp_image_url
      * @param string filename
      */
-    get_stamp_image_url : function(filename) {
+    get_stamp_image_url: function(filename) {
         var urls = this.get('stampfiles'),
             fullurl = '';
 
@@ -576,7 +577,7 @@ EDITOR.prototype = {
      * @protected
      * @method setup_toolbar
      */
-    setup_toolbar : function() {
+    setup_toolbar: function() {
         var toolnode,
             commentcolourbutton,
             annotationcolourbutton,
@@ -608,7 +609,7 @@ EDITOR.prototype = {
             buttonNode: commentcolourbutton,
             colours: COMMENTCOLOUR,
             iconprefix: 'background_colour_',
-            callback: function (e) {
+            callback: function(e) {
                 var colour = e.target.getAttribute('data-colour');
                 if (!colour) {
                     colour = e.target.ancestor().getAttribute('data-colour');
@@ -624,7 +625,7 @@ EDITOR.prototype = {
             buttonNode: annotationcolourbutton,
             iconprefix: 'colour_',
             colours: ANNOTATIONCOLOUR,
-            callback: function (e) {
+            callback: function(e) {
                 var colour = e.target.getAttribute('data-colour');
                 if (!colour) {
                     colour = e.target.ancestor().getAttribute('data-colour');
@@ -672,7 +673,7 @@ EDITOR.prototype = {
      * @protected
      * @method handle_tool_button
      */
-    handle_tool_button : function(e, tool) {
+    handle_tool_button: function(e, tool) {
         var currenttoolnode;
 
         e.preventDefault();
@@ -695,7 +696,7 @@ EDITOR.prototype = {
      * @method stringify_current_page
      * @return string
      */
-    stringify_current_page : function() {
+    stringify_current_page: function() {
         var comments = [],
             annotations = [],
             page,
@@ -708,7 +709,7 @@ EDITOR.prototype = {
             annotations[i] = this.pages[this.currentpage].annotations[i].clean();
         }
 
-        page = { comments : comments, annotations : annotations };
+        page = {comments: comments, annotations: annotations};
 
         return Y.JSON.stringify(page);
     },
@@ -718,7 +719,7 @@ EDITOR.prototype = {
      * @protected
      * @method get_current_drawable
      */
-    get_current_drawable : function() {
+    get_current_drawable: function() {
         var comment,
             annotation,
             drawable = false;
@@ -745,7 +746,7 @@ EDITOR.prototype = {
      * @protected
      * @method get_dialogue_element
      */
-    get_dialogue_element : function(selector) {
+    get_dialogue_element: function(selector) {
         if (this.panel) {
             return this.panel.one(selector);
         } else {
@@ -758,7 +759,7 @@ EDITOR.prototype = {
      * @protected
      * @method redraw_active_edit
      */
-    redraw_current_edit : function() {
+    redraw_current_edit: function() {
         if (this.currentdrawable) {
             this.currentdrawable.erase();
         }
@@ -771,14 +772,14 @@ EDITOR.prototype = {
      * @param Event
      * @method edit_start
      */
-    edit_start : function(e) {
+    edit_start: function(e) {
         e.preventDefault();
         var canvas = this.get_dialogue_element(SELECTOR.DRAWINGCANVAS),
             offset = canvas.getXY(),
             scrolltop = canvas.get('docScrollY'),
             scrollleft = canvas.get('docScrollX'),
-            point = {x : e.clientX - offset[0] + scrollleft,
-                     y : e.clientY - offset[1] + scrolltop},
+            point = {x: e.clientX - offset[0] + scrollleft,
+                     y: e.clientY - offset[1] + scrolltop},
             selected = false,
             lastannotation;
 
@@ -797,7 +798,7 @@ EDITOR.prototype = {
 
         this.currentedit.starttime = new Date().getTime();
         this.currentedit.start = point;
-        this.currentedit.end = {x : point.x, y : point.y};
+        this.currentedit.end = {x: point.x, y: point.y};
 
         if (this.currentedit.tool === 'select') {
             var x = this.currentedit.end.x,
@@ -830,8 +831,8 @@ EDITOR.prototype = {
         }
         if (this.currentannotation) {
             // Used to calculate drag offset.
-            this.currentedit.annotationstart = { x : this.currentannotation.x,
-                                                 y : this.currentannotation.y };
+            this.currentedit.annotationstart = {x: this.currentannotation.x,
+                                                 y: this.currentannotation.y};
         }
     },
 
@@ -841,7 +842,7 @@ EDITOR.prototype = {
      * @param Event
      * @method edit_move
      */
-    edit_move : function(e) {
+    edit_move: function(e) {
         e.preventDefault();
         var bounds = this.get_canvas_bounds(),
             canvas = this.get_dialogue_element(SELECTOR.DRAWINGCANVAS),
@@ -863,7 +864,7 @@ EDITOR.prototype = {
 
         if (this.currentedit.tool === 'select') {
             if (this.currentannotation && this.currentedit) {
-                this.currentannotation.move( this.currentedit.annotationstart.x + point.x - this.currentedit.start.x,
+                this.currentannotation.move(this.currentedit.annotationstart.x + point.x - this.currentedit.start.x,
                                              this.currentedit.annotationstart.y + point.y - this.currentedit.start.y);
             }
         } else if (this.currentedit.tool === 'drag') {
@@ -887,7 +888,7 @@ EDITOR.prototype = {
      * @param Event
      * @method edit_end
      */
-    edit_end : function() {
+    edit_end: function() {
         var duration,
             comment,
             annotation;
@@ -938,7 +939,7 @@ EDITOR.prototype = {
      * @public
      * @method resize
      */
-    resize : function() {
+    resize: function() {
         var drawingregion, drawregionheight;
 
         if (this.dialogue) {
@@ -955,7 +956,7 @@ EDITOR.prototype = {
         }
         drawingregion = this.get_dialogue_element(SELECTOR.DRAWINGREGION);
         if (this.dialogue) {
-            drawingregion.setStyle('maxHeight', drawregionheight +'px');
+            drawingregion.setStyle('maxHeight', drawregionheight + 'px');
         }
         this.redraw();
         return true;
@@ -966,7 +967,7 @@ EDITOR.prototype = {
      * @public
      * @method create_annotation
      */
-    create_annotation : function(type, data) {
+    create_annotation: function(type, data) {
         data.type = type;
         data.editor = this;
         if (type === "line") {
@@ -990,7 +991,7 @@ EDITOR.prototype = {
      * @protected
      * @method save_current_page
      */
-    save_current_page : function() {
+    save_current_page: function() {
         var ajaxurl = AJAXBASE,
             config;
 
@@ -998,14 +999,14 @@ EDITOR.prototype = {
             method: 'post',
             context: this,
             sync: false,
-            data : {
-                'sesskey' : M.cfg.sesskey,
-                'action' : 'savepage',
-                'index' : this.currentpage,
-                'userid' : this.get('userid'),
-                'attemptnumber' : this.get('attemptnumber'),
-                'assignmentid' : this.get('assignmentid'),
-                'page' : this.stringify_current_page()
+            data: {
+                'sesskey': M.cfg.sesskey,
+                'action': 'savepage',
+                'index': this.currentpage,
+                'userid': this.get('userid'),
+                'attemptnumber': this.get('attemptnumber'),
+                'assignmentid': this.get('assignmentid'),
+                'page': this.stringify_current_page()
             },
             on: {
                 success: function(tid, response) {
@@ -1046,10 +1047,10 @@ EDITOR.prototype = {
      * @protected
      * @method open_search_comments
      */
-    open_search_comments : function(e) {
+    open_search_comments: function(e) {
         if (!this.searchcommentswindow) {
             this.searchcommentswindow = new M.assignfeedback_editpdf.commentsearch({
-                editor : this
+                editor: this
             });
         }
 
@@ -1062,7 +1063,7 @@ EDITOR.prototype = {
      * @protected
      * @method redraw
      */
-    redraw : function() {
+    redraw: function() {
         var i,
             page;
 
@@ -1087,7 +1088,7 @@ EDITOR.prototype = {
      * @protected
      * @method change_page
      */
-    change_page : function() {
+    change_page: function() {
         var drawingcanvas = this.get_dialogue_element(SELECTOR.DRAWINGCANVAS),
             page,
             previousbutton,
@@ -1125,7 +1126,7 @@ EDITOR.prototype = {
      * @protected
      * @method setup_navigation
      */
-    setup_navigation : function() {
+    setup_navigation: function() {
         var pageselect,
             i,
             strinfo,
@@ -1140,7 +1141,7 @@ EDITOR.prototype = {
             for (i = 0; i < this.pages.length; i++) {
                 option = Y.Node.create('<option/>');
                 option.setAttribute('value', i);
-                strinfo = {page: i+1, total: this.pages.length};
+                strinfo = {page: i + 1, total: this.pages.length};
                 option.setHTML(M.util.get_string('pagexofy', 'assignfeedback_editpdf', strinfo));
                 pageselect.append(option);
             }
@@ -1165,7 +1166,7 @@ EDITOR.prototype = {
      * @protected
      * @method previous_page
      */
-    previous_page : function(e) {
+    previous_page: function(e) {
         e.preventDefault();
         this.currentpage--;
         if (this.currentpage < 0) {
@@ -1179,7 +1180,7 @@ EDITOR.prototype = {
      * @protected
      * @method next_page
      */
-    next_page : function(e) {
+    next_page: function(e) {
         e.preventDefault();
         this.currentpage++;
         if (this.currentpage >= this.pages.length) {
@@ -1208,51 +1209,51 @@ EDITOR.prototype = {
 };
 
 Y.extend(EDITOR, Y.Base, EDITOR.prototype, {
-    NAME : 'moodle-assignfeedback_editpdf-editor',
-    ATTRS : {
-        userid : {
-            validator : Y.Lang.isInteger,
-            value : 0
+    NAME: 'moodle-assignfeedback_editpdf-editor',
+    ATTRS: {
+        userid: {
+            validator: Y.Lang.isInteger,
+            value: 0
         },
-        assignmentid : {
-            validator : Y.Lang.isInteger,
-            value : 0
+        assignmentid: {
+            validator: Y.Lang.isInteger,
+            value: 0
         },
-        attemptnumber : {
-            validator : Y.Lang.isInteger,
-            value : 0
+        attemptnumber: {
+            validator: Y.Lang.isInteger,
+            value: 0
         },
-        header : {
-            validator : Y.Lang.isString,
-            value : ''
+        header: {
+            validator: Y.Lang.isString,
+            value: ''
         },
-        body : {
-            validator : Y.Lang.isString,
-            value : ''
+        body: {
+            validator: Y.Lang.isString,
+            value: ''
         },
-        footer : {
-            validator : Y.Lang.isString,
-            value : ''
+        footer: {
+            validator: Y.Lang.isString,
+            value: ''
         },
-        linkid : {
-            validator : Y.Lang.isString,
-            value : ''
+        linkid: {
+            validator: Y.Lang.isString,
+            value: ''
         },
-        deletelinkid : {
-            validator : Y.Lang.isString,
-            value : ''
+        deletelinkid: {
+            validator: Y.Lang.isString,
+            value: ''
         },
-        readonly : {
-            validator : Y.Lang.isBoolean,
-            value : true
+        readonly: {
+            validator: Y.Lang.isBoolean,
+            value: true
         },
-        stampfiles : {
-            validator : Y.Lang.isArray,
-            value : ''
+        stampfiles: {
+            validator: Y.Lang.isArray,
+            value: ''
         },
-        pagetotal : {
-            validator : Y.Lang.isInteger,
-            value : 0
+        pagetotal: {
+            validator: Y.Lang.isInteger,
+            value: 0
         }
     }
 });
@@ -1267,6 +1268,6 @@ M.assignfeedback_editpdf.editor = M.assignfeedback_editpdf.editor || {};
  * @param {Object} params
  */
 M.assignfeedback_editpdf.editor.init = M.assignfeedback_editpdf.editor.init || function(params) {
-    M.assignfeedback_editpdf.instance =  new EDITOR(params);
+    M.assignfeedback_editpdf.instance = new EDITOR(params);
     return M.assignfeedback_editpdf.instance;
 };
